﻿using System.Drawing;

using DevExpress.Data;
using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridView.InitializeView
            (
                true,                           // Multi Select
                GridMultiSelectMode.CellSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,   // Draw Focus Rect Style
                true,                           // Show Indicator
                true,                           // Show Column Headers
                true,                           // Allow Column Moving
                true,                           // Allow Column Resizing
                true,                           // Allow Filter
                true,                           // Allow Sort
                false,                          // Allow Cell Merge
                EditorShowMode.Default,         // Editor Show Mode
                false                           // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridView.OptionsView.ShowFooter = true;

            this.gridView.PaintStyleName = "Flat";

            this.gridControl.DataSource = new nwindDataSetTableAdapters.ProductsTableAdapter().GetData();

            GridColumnSummaryItem productNameSummaryItem  = new GridColumnSummaryItem();

            productNameSummaryItem.FieldName     = "ProductName";
            productNameSummaryItem.SummaryType   = SummaryItemType.Count;
            productNameSummaryItem.DisplayFormat = "건수 : {0:n0}";

            this.gridView.Columns["ProductName"].Summary.Add(productNameSummaryItem);

            GridColumnSummaryItem unitPriceSummaryItem  = new GridColumnSummaryItem();

            unitPriceSummaryItem.FieldName     = "UnitPrice";
            unitPriceSummaryItem.SummaryType   = SummaryItemType.Max;
            unitPriceSummaryItem.DisplayFormat = "최고액 : {0:c2}";

            this.gridView.Columns["UnitPrice"].Summary.Add(unitPriceSummaryItem);

            GridColumnSummaryItem unitsInStockSummaryItem  = new GridColumnSummaryItem();

            unitsInStockSummaryItem.FieldName     = "UnitsInStock";
            unitsInStockSummaryItem.SummaryType   = SummaryItemType.Average;
            unitsInStockSummaryItem.DisplayFormat = "평균 : {0:c2}";

            this.gridView.Columns["UnitsInStock"].Summary.Add(unitsInStockSummaryItem);

            this.gridView.BestFitColumns();

            this.gridView.CustomDrawFooterCell += gridView_CustomDrawFooterCell;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 그리드 뷰 바닥글 셀 커스텀 그리기 - gridView_CustomDrawFooterCell(sender, e)

        /// <summary>
        /// 그리드 뷰 바닥글 셀 커스텀 그리기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_CustomDrawFooterCell(object sender, FooterCellCustomDrawEventArgs e)
        {
            if(e.Column.SummaryItem.SummaryType == SummaryItemType.Count)
            {
                e.Appearance.BackColor = Color.Pink;
            }
            else if(e.Column.SummaryItem.SummaryType == SummaryItemType.Average)
            {
                e.Appearance.BackColor = Color.Thistle;
            }
            else
            {
                e.Appearance.BackColor = Color.Moccasin;
            }
        }

        #endregion
    }
}